@@ -39,6 +39,57 @@ function safe_ipv4($param_name){
     return $_REQUEST[$param_name];
 }
 
+# IPv6
+function validate_ipv6($ip){
+    if(!isset($_REQUEST[$ip]) || $_REQUEST[$ip] == ""){
+        return FALSE;
+    }
+    $param = $_REQUEST[$ip];
+    $reg = "/^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))\$/";
+# Lamely taken from https://stackoverflow.com/questions/53497/regular-expression-that-matches-valid-ipv6-addresses
+#
+# It should match:
+#
+#    IPv6 addresses
+#    zero compressed IPv6 addresses (section 2.2 of rfc5952)
+#    link-local IPv6 addresses with zone index (section 11 of rfc4007)
+#    IPv4-Embedded IPv6 Address (section 2 of rfc6052)
+#    IPv4-mapped IPv6 addresses (section 2.1 of rfc2765)
+#    IPv4-translated addresses (section 2.1 of rfc2765)
+#
+# For ease of reading, the following is the above regular expression split at major OR points into separate lines:
+#
+# IPv6 RegEx
+# (
+# ([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|          # 1:2:3:4:5:6:7:8
+# ([0-9a-fA-F]{1,4}:){1,7}:|                         # 1::                              1:2:3:4:5:6:7::
+# ([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|         # 1::8             1:2:3:4:5:6::8  1:2:3:4:5:6::8
+# ([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|  # 1::7:8           1:2:3:4:5::7:8  1:2:3:4:5::8
+# ([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|  # 1::6:7:8         1:2:3:4::6:7:8  1:2:3:4::8
+# ([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|  # 1::5:6:7:8       1:2:3::5:6:7:8  1:2:3::8
+# ([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|  # 1::4:5:6:7:8     1:2::4:5:6:7:8  1:2::8
+# [0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|       # 1::3:4:5:6:7:8   1::3:4:5:6:7:8  1::8
+# :((:[0-9a-fA-F]{1,4}){1,7}|:)|                     # ::2:3:4:5:6:7:8  ::2:3:4:5:6:7:8 ::8       ::
+# fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|     # fe80::7:8%eth0   fe80::7:8%1     (link-local IPv6 addresses with zone index)
+# ::(ffff(:0{1,4}){0,1}:){0,1}
+# ((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}
+# (25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|          # ::255.255.255.255   ::ffff:255.255.255.255  ::ffff:0:255.255.255.255  (IPv4-mapped IPv6 addresses and IPv4-translated addresses)
+# ([0-9a-fA-F]{1,4}:){1,4}:
+# ((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}
+# (25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])           # 2001:db8:3:4::192.0.2.33  64:ff9b::192.0.2.33 (IPv4-Embedded IPv6 Address)
+# )
+
+    if(!preg_match($reg,$param))       return FALSE;
+    else                    return TRUE;
+}
+
+function safe_ipv6($param_name){
+    if(validate_ipv6($param_name) === FALSE){
+        return FALSE;
+    }
+    return $_REQUEST[$param_name];
+}
+
 function validate_uuid($uuid){
     if(!isset($_REQUEST[$uuid]) || $_REQUEST[$uuid] == ""){
        return FALSE;
@@ -125,7 +176,7 @@ function validate_password($password){
         return FALSE;
     }
     $param = $_REQUEST[$password];
-    $reg = '/^[-a-zA-Z0-9_,+ :@.]+$/';
+    $reg = '/^[-a-zA-Z0-9\/_,+ :@.]+$/';
     if(!preg_match($reg,$param))       return FALSE;
      else                    return TRUE;
 }
@@ -143,7 +194,7 @@ function validate_serial($serial){
         return FALSE;
     }
     $param = $_REQUEST[$serial];
-    $reg = "/^[-a-zA-Z0-9]+\$/";
+    $reg = "/^[-a-zA-Z0-9.]+\$/";
     if(!preg_match($reg,$param))       return FALSE;
      else                    return TRUE;
 }
